@@ -6,6 +6,7 @@ use {
     },
     chrono::{Local, TimeZone},
     console::{style, Emoji},
+    crossbeam_channel::unbounded,
     indicatif::{ProgressBar, ProgressStyle},
     serde::{Deserialize, Serialize},
     solana_client::rpc_client::RpcClient,
@@ -21,7 +22,6 @@ use {
         fs::{self, File},
         io::{self, BufReader, Read},
         path::{Path, PathBuf},
-        sync::mpsc,
         time::{Duration, Instant, SystemTime},
     },
     tempfile::TempDir,
@@ -1196,7 +1196,7 @@ pub fn run(
     let mut child_option: Option<std::process::Child> = None;
     let mut now = Instant::now();
 
-    let (signal_sender, signal_receiver) = mpsc::channel();
+    let (signal_sender, signal_receiver) = unbounded();
     ctrlc::set_handler(move || {
         let _ = signal_sender.send(());
     })
